@@ -3,7 +3,7 @@
    | PHP Version 5 / Imagick	                                          |
    +----------------------------------------------------------------------+
    | Copyright (c) 2006-2013 Mikko Koppanen, Scott MacVicar               |
-   | Imagemagick (c) ImageMagick Studio LLC                               |
+   | ImageMagick (c) ImageMagick Studio LLC                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -23,8 +23,10 @@
 
 /* Define Extension Properties */
 #define PHP_IMAGICK_EXTNAME    "imagick"
-#define PHP_IMAGICK_VERSION    "3.4.2"
-#define PHP_IMAGICK_EXTNUM     30402
+// The version is deliberately left as 'PACKAGE_VERSION' in source code.
+// It is only replaced with the actual version number that packaged through pecl.php.net
+#define PHP_IMAGICK_VERSION    "3.6.0"
+#define PHP_IMAGICK_EXTNUM     30600
 
 /* Import configure options when building 
    outside of the PHP source tree */
